Welcome to ASTROMER documentation! — ASTROMER 0.0.6 documentation

# Welcome to ASTROMER documentation!

ASTROMER is a transformer based model pretrained on millions of light curves. ASTROMER can be finetuned on specific datasets to create useful representations that can improve the performance of novel deep learning models.

❗ This version of ASTROMER can only works on single band light curves.

This project was published by C. Donoso-Oliva, I. Becker, P. Protopapas, G. Cabrera-Vives, M. Vishnu and H. Vardhan, 2023, A&A, 670, A54.

Important

This sample documentation was generated on Feb 24, 2023, and is rebuilt weekly.

LIBRARY DOCUMENTATION

- ASTROMER
  - Models
  - Single-Band Encoder
    - `SingleBandEncoder`
      - `SingleBandEncoder.encode()`
      - `SingleBandEncoder.fit()`
      - `SingleBandEncoder.from_pretraining()`
      - `SingleBandEncoder.load_weights()`
  - Preprocessing
    - `make_pretraining()`
  - Utils
    - `download_weights()`
  - Quick-start
    - Fine Tune

## Resources

- ASTROMER Documentation

- ASTROMER Tutorials

## Contributing to ASTROMER

> If you train your model from scratch, you can share your pre-trained weights by submitting a Pull Request on the weights repository